#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar-conduit
version:              0.3.2
visibility:           public
id:                   tar-conduit-0.3.2-IatGl7EIOMh68FCdScy5xH
key:                  tar-conduit-0.3.2-IatGl7EIOMh68FCdScy5xH
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  ba7890ffe9b0bffe06bf84388227a9e6
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tar-conduit-0.3.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tar-conduit-0.3.2
hs-libraries:         HStar-conduit-0.3.2-IatGl7EIOMh68FCdScy5xH
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE directory-1.3.6.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.1-5k5YUvh9EUEA8260dxkQvv
    text-1.2.4.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

